'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var webUiCore = require('@orioro/web-ui-core');
var createFocusTrap = _interopDefault(require('focus-trap'));
require('classlist.js');

var DIALOG_COMPONENT_NAME = 'dialog';

var createInstance = function createInstance(system, componentRoot) {
  var _ref = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {},
      _ref$activeClass = _ref.activeClass,
      activeClass = _ref$activeClass === void 0 ? 'active' : _ref$activeClass,
      _ref$navigatable = _ref.navigatable,
      navigatable = _ref$navigatable === void 0 ? false : _ref$navigatable,
      _ref$preventMovingToB = _ref.preventMovingToBody,
      preventMovingToBody = _ref$preventMovingToB === void 0 ? false : _ref$preventMovingToB,
      _ref$interactionTarge = _ref.interactionTarget,
      interactionTarget = _ref$interactionTarge === void 0 ? null : _ref$interactionTarge,
      _ref$onOpenAction = _ref.onOpenAction,
      onOpenAction = _ref$onOpenAction === void 0 ? null : _ref$onOpenAction,
      _ref$onCloseAction = _ref.onCloseAction,
      onCloseAction = _ref$onCloseAction === void 0 ? null : _ref$onCloseAction;

  var state = {
    active: false
  };

  if (!preventMovingToBody) {
    componentRoot.remove();
    document.querySelector('body').appendChild(componentRoot);
  }

  interactionTarget = interactionTarget ? componentRoot.querySelector(interactionTarget) : null;
  var focusTrap = createFocusTrap(componentRoot);

  var open = function open() {
    if (!state.active) {
      system.getComponentInstances(DIALOG_COMPONENT_NAME).forEach(function (instance) {
        instance.close();
      });
      componentRoot.classList.add(activeClass);
      focusTrap.activate(interactionTarget ? interactionTarget : '[autofocus]');
      state.active = true;

      if (interactionTarget && onOpenAction) {
        system.invoke(interactionTarget, null, onOpenAction);
      }
    }
  };

  var close = function close() {
    if (state.active) {
      if (navigatable) {
        system.navHistoryReplaceState('#');
      }

      focusTrap.deactivate();
      componentRoot.classList.remove(activeClass);
      state.active = false;

      if (interactionTarget && onCloseAction) {
        system.invoke(interactionTarget, null, onCloseAction);
      }
    }
  };

  var dismiss = function dismiss() {
    close();
  };

  componentRoot.addEventListener('click', function (e) {
    if (e.target === componentRoot) {
      dismiss();
    }
  });
  document.addEventListener('keyup', function (e) {
    if (state.active && e.keyCode === 27) {
      dismiss();
    }
  });
  return {
    state: state,
    open: open,
    close: close,
    dismiss: dismiss,
    defaultAction: open
  };
};

var dialog = function dialog() {
  return {
    componentName: DIALOG_COMPONENT_NAME,
    instancePropTypes: {
      activeClass: webUiCore.PropTypes.string,
      navigatable: webUiCore.PropTypes.bool,
      preventMovingToBody: webUiCore.PropTypes.bool,
      interactionTarget: webUiCore.PropTypes.string,
      onOpenAction: webUiCore.PropTypes.string,
      onCloseAction: webUiCore.PropTypes.string
    },
    createInstance: createInstance
  };
};

exports.dialog = dialog;
